<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:fn="http://www.w3.org/2005/xpath-functions/">
	<xsl:output method="html"/>	
	<xsl:template match="/">
		<html>
			<title>ECMPS Monitoring Plan XML Data File</title>
			<body>
				<h2 style="color:darkblue">ECMPS Monitoring Plan XML Data File</h2>
				<p/>
				<!-- Facility Details Part 1 -->
				<table border="0" width="100%">
					<tbody>
						<tr>
							<td style="color:white;background-color:darkblue;">Facility Details</td>
						</tr>
					</tbody>
				</table>
				<!-- Facility Details Part 2 -->
				<table border="0" title="Facility Details">
					<tbody>
						<tr>
							<td width="250">Facility ID (ORISPL):</td>
							<td>
								<xsl:value-of select="MonitoringPlan/ORISCode"/>
							</td>
						</tr>
						<tr>
							<td width="250">XSD Version:</td>
							<td>
								<xsl:value-of select="MonitoringPlan/Version"/>
							</td>
						</tr>
						<xsl:for-each select="MonitoringPlan/MonitoringLocationData">
							<tr>
								<xsl:choose>
									<xsl:when test="StackPipeID">
										<td width="250">Stack/Pipe Identifier:</td>
										<td><xsl:value-of select="StackPipeID"/></td>
									</xsl:when>
									<xsl:otherwise>
										<td width="250">Unit Identifier:</td>
										<td><xsl:value-of select="UnitID"/></td>
									</xsl:otherwise>
								</xsl:choose>
							</tr>
						</xsl:for-each>
					</tbody>
				</table>
				<!-- Stack Pipe info -->
				<xsl:if test="MonitoringPlan/MonitoringLocationData/StackPipeData">
					<br/>				
					<table title="Stacks and Pipes" border="1" width="100%" style="border-color:darkblue;border-width:1px;background-color:White;">
					   <caption style="color:darkblue;text-align:left;">Stacks and Pipes</caption>
						<tbody>
							<tr style="color:white;background-color:darkblue;">
								<th>Stack/Pipe Identifier</th>
								<th>Activation Date</th>
								<th>Retirement Date</th>
							</tr>
							<xsl:for-each select="MonitoringPlan/MonitoringLocationData[StackPipeID != '']">
								<tr>
									<td><xsl:value-of select="StackPipeID"/></td>
									<td><xsl:value-of select="StackPipeData/ActiveDate"/></td>
									<xsl:if test="StackPipeData/RetireDate = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="StackPipeData/RetireDate != ''"><td><xsl:value-of select="StackPipeData/RetireDate"/></td></xsl:if>
								</tr>
							</xsl:for-each>
						</tbody>
					</table>
				</xsl:if>				
				<!-- Only add unit stack config info if they exist in the file -->
				<xsl:if test="MonitoringPlan/UnitStackConfigurationData">
					<br/>
					<table title="Unit Stack Configuration" border="1" width="100%" style="border-color:darkblue;border-width:1px;background-color:White;">
					   <caption style="color:darkblue;text-align:left;">Unit to Stack/Pipe Relationship</caption>
						<tbody>
							<tr style="color:white;background-color:darkblue;">
								<th>Stack/Pipe Identifier</th>
								<th>Associated Units</th>
								<th>Begin Date</th>
								<th>End Date</th>
							</tr>
							<xsl:for-each select="MonitoringPlan/UnitStackConfigurationData">
								<tr>
									<td><xsl:value-of select="StackPipeID"/></td>
									<td><xsl:value-of select="UnitID"/></td>
									<td><xsl:value-of select="BeginDate"/></td>
									<xsl:call-template name="Optional_EndDate_Template"/>
								</tr>
							</xsl:for-each>
						</tbody>
					</table>
				</xsl:if>				
				<!-- Monitor Location Attribute -->
				<xsl:if test="MonitoringPlan/MonitoringLocationData/StackPipeData/MonitoringLocationAttribData | MonitoringPlan/MonitoringLocationData/UnitData/MonitoringLocationAttribData">
					<br/>				
					<table title="Monitoring Location Attributes" border="1" width="100%" style="border-color:darkblue;border-width:1px;background-color:White;">
					   <caption style="color:darkblue;text-align:left;">Monitoring Location Attributes</caption>
						<tbody>
							<tr style="color:white;background-color:darkblue;">
								<th>Unit/Stack/Pipe Identifier</th>
								<th>Duct Indicator</th>
								<th>Bypass Indicator</th>
								<th>Ground Elevation (ft)</th>
								<th>Stack Height (ft)</th>
								<th>Material Code</th>
								<th>Shape Code</th>
								<th>Cross Area Flow (sq. ft)</th>
								<th>Cross Area Stack Exit (sq. ft)</th>
								<th>Begin Date</th>
								<th>End Date</th>
							</tr>
							<xsl:for-each select="MonitoringPlan/MonitoringLocationData/StackPipeData/MonitoringLocationAttribData | MonitoringPlan/MonitoringLocationData/UnitData/MonitoringLocationAttribData">
								<tr>
									<xsl:choose>
										<xsl:when test="../../StackPipeID != ''">
											<td><xsl:value-of select="../../StackPipeID"/></td>
										</xsl:when>
										<xsl:otherwise>
											<td><xsl:value-of select="../../UnitID"/></td>
										</xsl:otherwise>
									</xsl:choose>
									<xsl:if test="DuctIndicator = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="DuctIndicator != ''"><td><xsl:value-of select="DuctIndicator"/></td></xsl:if>
									<xsl:if test="BypassIndicator = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="BypassIndicator != ''"><td><xsl:value-of select="BypassIndicator"/></td></xsl:if>
									<xsl:if test="GroundElevation = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="GroundElevation != ''"><td><xsl:value-of select="GroundElevation"/></td></xsl:if>
									<xsl:if test="StackHeight = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="StackHeight != ''"><td><xsl:value-of select="StackHeight"/></td></xsl:if>
									<xsl:if test="MaterialCode = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="MaterialCode != ''"><td><xsl:value-of select="MaterialCode"/></td></xsl:if>
									<xsl:if test="ShapeCode = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="ShapeCode != ''"><td><xsl:value-of select="ShapeCode"/></td></xsl:if>
									<xsl:if test="CrossAreaFlow = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="CrossAreaFlow != ''"><td><xsl:value-of select="CrossAreaFlow"/></td></xsl:if>
									<xsl:if test="CrossAreaStackExit = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="CrossAreaStackExit != ''"><td><xsl:value-of select="CrossAreaStackExit"/></td></xsl:if>
									<td><xsl:value-of select="BeginDate"/></td>
									<xsl:call-template name="Optional_EndDate_Template"/>
								</tr>
							</xsl:for-each>
						</tbody>
					</table>
				</xsl:if>				
				<!-- Unit Capacity Data -->
				<xsl:if test="MonitoringPlan/MonitoringLocationData/UnitData">
					<br/>
					<table title="Units" border="1" width="100%" style="background-color:White;">
						<caption style="color:darkblue;text-align:left;">Units</caption>
						<tbody>
							<tr style="color:white;background-color:darkblue;">
								<th>Unit Identifier</th>
								<th>Non Load Based Indicator</th>
							</tr>
							<xsl:for-each select="MonitoringPlan/MonitoringLocationData/UnitData">
								<xsl:sort select="../UnitID"/>
								<tr>
									<td><xsl:value-of select="../UnitID"/></td>
									<td><xsl:value-of select="NonLoadBasedIndicator"/></td>
								</tr>
							</xsl:for-each>
						</tbody>
					</table>
				</xsl:if>								<!-- Unit Capacity Data -->
				<xsl:if test="MonitoringPlan/MonitoringLocationData/UnitData/UnitCapacityData">
					<br/>
					<table title="Unit Capacity Data" border="1" width="100%" style="background-color:White;">
						<caption style="color:darkblue;text-align:left;">Unit Capacity Data</caption>
						<tbody>
							<tr style="color:white;background-color:darkblue;">
								<th>Unit Identifier</th>
								<th>Max Hourly Heat Input Capacity (mmBtu/hr)</th>
								<th>Begin Date</th>
								<th>End Date</th>
							</tr>
							<xsl:for-each select="MonitoringPlan/MonitoringLocationData/UnitData/UnitCapacityData">
								<xsl:sort select="BeginDate"/>
								<tr>
									<td><xsl:value-of select="../../UnitID"/></td>
									<td><xsl:value-of select="MaximumHourlyHeatInputCapacity"/></td>
									<td><xsl:value-of select="BeginDate"/></td>
									<xsl:call-template name="Optional_EndDate_Template"/>
								</tr>
							</xsl:for-each>
						</tbody>
					</table>
				</xsl:if>				
				<!-- Unit Fuel -->
				<xsl:if test="MonitoringPlan/MonitoringLocationData/UnitData/UnitFuelData">
					<br/>
					<table title="Unit Fuel" border="1" width="100%" style="background-color:White;">
						<caption style="color:darkblue;text-align:left;">Unit Fuel</caption>
						<tbody>
							<tr style="color:white;background-color:darkblue;">
								<th>Unit Identifier</th>
								<th>Fuel Type</th>
								<th>Fuel Indicator</th>
								<th>Demonstration Method for GCV</th>
								<th>Demonstration Method for Daily Sulfur</th>
								<th>Ozone Season Indicator</th>
								<th>Begin Date</th>
								<th>End Date</th>
							</tr>
							<xsl:for-each select="MonitoringPlan/MonitoringLocationData/UnitData/UnitFuelData">
								<xsl:sort select="BeginDate"/>
								<tr>
									<td><xsl:value-of select="../../UnitID"/></td>
									<td><xsl:value-of select="FuelCode"/></td>
									<xsl:if test="IndicatorCode = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="IndicatorCode != ''"><td><xsl:value-of select="IndicatorCode"/></td></xsl:if>
									<xsl:if test="OzoneSeasonIndicator = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="OzoneSeasonIndicator != ''"><td><xsl:value-of select="OzoneSeasonIndicator"/></td></xsl:if>
									<xsl:if test="DemGCV = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="DemGCV != ''"><td><xsl:value-of select="DemGCV"/></td></xsl:if>
									<xsl:if test="DemSO2 = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="DemSO2 != ''"><td><xsl:value-of select="DemSO2"/></td></xsl:if>
									<td><xsl:value-of select="BeginDate"/></td>
									<xsl:call-template name="Optional_EndDate_Template"/>
								</tr>
							</xsl:for-each>
						</tbody>
					</table>
				</xsl:if>				
				<!-- Unit Controls -->
				<xsl:if test="MonitoringPlan/MonitoringLocationData/UnitData/UnitControlData">
					<br/>
					<table title="Unit Controls" border="1" width="100%" style="background-color:White;">
						<caption style="color:darkblue;text-align:left;">Unit Controls</caption>
						<tbody>
							<tr style="color:white;background-color:darkblue;">
								<th>Unit Identifier</th>
								<th>Parameter</th>
								<th>Control Equipment</th>
								<th>Original Indicator</th>
								<th>Seasonal Indicator</th>
								<th>Install Date</th>
								<th>Optimization Date</th>
								<th>Retirement Date</th>
							</tr>
							<xsl:for-each select="MonitoringPlan/MonitoringLocationData/UnitData/UnitControlData">
								<xsl:sort select="BeginDate"/>
								<tr>
									<td><xsl:value-of select="../../UnitID"/></td>
									<td><xsl:value-of select="ParameterCode"/></td>
									<td><xsl:value-of select="ControlCode"/></td>
									<xsl:if test="OriginalCode = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="OriginalCode != ''"><td><xsl:value-of select="OriginalCode"/></td></xsl:if>
									<xsl:if test="SeasonalControlsIndicator = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="SeasonalControlsIndicator != ''"><td><xsl:value-of select="SeasonalControlsIndicator"/></td></xsl:if>
									<xsl:if test="InstallDate = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="InstallDate != ''"><td><xsl:value-of select="InstallDate"/></td></xsl:if>
									<xsl:if test="OptimizationDate = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="OptimizationDate != ''"><td><xsl:value-of select="OptimizationDate"/></td></xsl:if>
									<xsl:if test="RetireDate = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="RetireDate != ''"><td><xsl:value-of select="RetireDate"/></td></xsl:if>
								</tr>
							</xsl:for-each>
						</tbody>
					</table>
				</xsl:if>				
				<!-- Monitoring Method -->
				<xsl:if test="MonitoringPlan/MonitoringLocationData/StackPipeData/MonitoringMethodData | MonitoringPlan/MonitoringLocationData/UnitData/MonitoringMethodData">
					<br/>
					<table title="Monitoring Method" border="1" width="100%" style="background-color:White;">
						<caption style="color:darkblue;text-align:left;">Monitoring Method</caption>
						<tbody>
							<tr style="color:white;background-color:darkblue;">
								<th>Unit/Stack/Pipe Identifier</th>
								<th>Parameter</th>
								<th>Methodology</th>
								<th>Substitute Data Approach</th>
								<th>Bypass Approach Code</th>
								<th>Begin Date</th>
								<th>Begin Hour</th>
								<th>End Date</th>
								<th>End Hour</th>
							</tr>
							<xsl:for-each select="MonitoringPlan/MonitoringLocationData/StackPipeData/MonitoringMethodData | MonitoringPlan/MonitoringLocationData/UnitData/MonitoringMethodData">
								<xsl:sort select="BeginDate"/>
								<tr>
									<xsl:choose>
										<xsl:when test="../../StackPipeID != ''">
											<td><xsl:value-of select="../../StackPipeID"/></td>
										</xsl:when>
										<xsl:otherwise>
											<td><xsl:value-of select="../../UnitID"/></td>
										</xsl:otherwise>
									</xsl:choose>
									<td><xsl:value-of select="ParameterCode"/></td>
									<td><xsl:value-of select="MonitoringMethodCode"/></td>
									<xsl:if test="SubstituteDataCode = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="SubstituteDataCode != ''"><td><xsl:value-of select="SubstituteDataCode"/></td></xsl:if>
									<xsl:if test="BypassApproachCode = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="BypassApproachCode != ''"><td><xsl:value-of select="BypassApproachCode"/></td></xsl:if>
									<td><xsl:value-of select="BeginDate"/></td>
									<td><xsl:value-of select="BeginHour"/></td>
									<xsl:call-template name="Optional_EndDate_Template"/>
									<xsl:call-template name="Optional_EndHour_Template"/>
								</tr>
							</xsl:for-each>
						</tbody>
					</table>
				</xsl:if>				
				<!-- MATS Supplemental Method -->
				<xsl:if test="MonitoringPlan/MonitoringLocationData/StackPipeData/SupplementalMATSMonitoringMethodData | MonitoringPlan/MonitoringLocationData/UnitData/SupplementalMATSMonitoringMethodData">
					<br/>
					<table title="Supplemental MATS Monitoring Method" border="1" width="100%" style="background-color:White;">
						<caption style="color:darkblue;text-align:left;">Supplemental MATS Monitoring Method</caption>
						<tbody>
							<tr style="color:white;background-color:darkblue;">
								<th>Unit/Stack/Pipe Identifier</th>
								<th>Parameter</th>
								<th>Methodology</th>
								<th>Begin Date</th>
								<th>Begin Hour</th>
								<th>End Date</th>
								<th>End Hour</th>
							</tr>
							<xsl:for-each select="MonitoringPlan/MonitoringLocationData/StackPipeData/SupplementalMATSMonitoringMethodData | MonitoringPlan/MonitoringLocationData/UnitData/SupplementalMATSMonitoringMethodData">
								<xsl:sort select="BeginDate"/>
								<tr>
									<xsl:choose>
										<xsl:when test="../../StackPipeID != ''">
											<td><xsl:value-of select="../../StackPipeID"/></td>
										</xsl:when>
										<xsl:otherwise>
											<td><xsl:value-of select="../../UnitID"/></td>
										</xsl:otherwise>
									</xsl:choose>
									<td><xsl:value-of select="SupplementalMATSParameterCode"/></td>
									<td><xsl:value-of select="SupplementalMATSMonitoringMethodCode"/></td>
									<td><xsl:value-of select="BeginDate"/></td>
									<td><xsl:value-of select="BeginHour"/></td>
									<xsl:call-template name="Optional_EndDate_Template"/>
									<xsl:call-template name="Optional_EndHour_Template"/>
								</tr>
							</xsl:for-each>
						</tbody>
					</table>
				</xsl:if>				
				<!-- Monitoring Systems -->
				<xsl:if test="MonitoringPlan/MonitoringLocationData/StackPipeData/MonitoringSystemData | MonitoringPlan/MonitoringLocationData/UnitData/MonitoringSystemData">
					<br/>
					<table title="Monitoring Systems" border="1" width="100%" style="background-color:White;">
						<caption style="color:darkblue;text-align:left;">Monitoring Systems</caption>
						<tbody>
							<tr style="color:white;background-color:darkblue;">
								<th>Unit/Stack/Pipe Identifier</th>
								<th>System ID</th>
								<th>System Type</th>
								<th>Des</th>
								<th>Fuel Code</th>
								<th>Begin Date</th>
								<th>Begin Hour</th>
								<th>End Date</th>
								<th>End Hour</th>
							</tr>
							<xsl:for-each select="MonitoringPlan/MonitoringLocationData/StackPipeData/MonitoringSystemData | MonitoringPlan/MonitoringLocationData/UnitData/MonitoringSystemData">
								<xsl:sort select="BeginDate"/>
								<tr>
									<xsl:choose>
										<xsl:when test="../../StackPipeID != ''">
											<td><xsl:value-of select="../../StackPipeID"/></td>
										</xsl:when>
										<xsl:otherwise>
											<td><xsl:value-of select="../../UnitID"/></td>
										</xsl:otherwise>
									</xsl:choose>
									<td><xsl:value-of select="MonitoringSystemID"/></td>
									<td><xsl:value-of select="SystemTypeCode"/></td>
									<xsl:if test="SystemDesignationCode = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="SystemDesignationCode != ''"><td><xsl:value-of select="SystemDesignationCode"/></td></xsl:if>
									<xsl:if test="FuelCode = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="FuelCode != ''"><td><xsl:value-of select="FuelCode"/></td></xsl:if>
									<xsl:call-template name="Optional_BeginDate_Template"/>
									<xsl:call-template name="Optional_BeginHour_Template"/>
									<xsl:call-template name="Optional_EndDate_Template"/>
									<xsl:call-template name="Optional_EndHour_Template"/>
								</tr>
							</xsl:for-each>
						</tbody>
					</table>
				</xsl:if>				
				<!-- System Components -->
				<xsl:if test="MonitoringPlan/MonitoringLocationData/StackPipeData/MonitoringSystemData/MonitoringSystemComponentData | MonitoringPlan/MonitoringLocationData/UnitData/MonitoringSystemData/MonitoringSystemComponentData">
					<br/>
					<table title="System Components" border="1" width="100%" style="background-color:White;">
						<caption style="color:darkblue;text-align:left;">System Components</caption>
						<tbody>
							<tr style="color:white;background-color:darkblue;">
								<th>Unit/Stack/Pipe Identifier</th>
								<th>System ID</th>
								<th>Fuel Code</th>
								<th>Component ID</th>
								<th>Begin Date</th>
								<th>Begin Hour</th>
								<th>End Date</th>
								<th>End Hour</th>
							</tr>
							<xsl:for-each select="MonitoringPlan/MonitoringLocationData/StackPipeData/MonitoringSystemData/MonitoringSystemComponentData | MonitoringPlan/MonitoringLocationData/UnitData/MonitoringSystemData/MonitoringSystemComponentData">
								<xsl:sort select="BeginDate"/>
								<tr>
									<xsl:choose>
										<xsl:when test="../../../StackPipeID != ''">
											<td><xsl:value-of select="../../../StackPipeID"/></td>
										</xsl:when>
										<xsl:otherwise>
											<td><xsl:value-of select="../../../UnitID"/></td>
										</xsl:otherwise>
									</xsl:choose>
									<td><xsl:value-of select="../MonitoringSystemID"/></td>
									<td><xsl:value-of select="../FuelCode"/></td>
									<td><xsl:value-of select="ComponentID"/></td>
									<xsl:call-template name="Optional_BeginDate_Template"/>
									<xsl:call-template name="Optional_BeginHour_Template"/>
									<xsl:call-template name="Optional_EndDate_Template"/>
									<xsl:call-template name="Optional_EndHour_Template"/>
								</tr>
							</xsl:for-each>
						</tbody>
					</table>
				</xsl:if>				
				<!-- Monitoring System Fuel Flow -->
				<xsl:if test="MonitoringPlan/MonitoringLocationData/StackPipeData/MonitoringSystemData/MonitoringSystemFuelFlowData | MonitoringPlan/MonitoringLocationData/UnitData/MonitoringSystemData/MonitoringSystemFuelFlowData">
					<br/>
					<table title="Monitoring System Fuel Flow" border="1" width="100%" style="background-color:White;">
						<caption style="color:darkblue;text-align:left;">Monitoring System Fuel Flow</caption>
						<tbody>
							<tr style="color:white;background-color:darkblue;">
								<th>Unit/Stack/Pipe Identifier</th>
								<th>System ID</th>
								<th>Fuel Code</th>
								<th>Max Fuel Flow Rate</th>
								<th>Units of Measure</th>
								<th>Source Code</th>
								<th>Begin Date</th>
								<th>Begin Hour</th>
								<th>End Date</th>
								<th>End Hour</th>
							</tr>
							<xsl:for-each select="MonitoringPlan/MonitoringLocationData/StackPipeData/MonitoringSystemData/MonitoringSystemFuelFlowData | MonitoringPlan/MonitoringLocationData/UnitData/MonitoringSystemData/MonitoringSystemFuelFlowData">
								<xsl:sort select="BeginDate"/>
								<tr>
									<xsl:choose>
										<xsl:when test="../../../StackPipeID != ''">
											<td><xsl:value-of select="../../../StackPipeID"/></td>
										</xsl:when>
										<xsl:otherwise>
											<td><xsl:value-of select="../../../UnitID"/></td>
										</xsl:otherwise>
									</xsl:choose>
									<td><xsl:value-of select="../MonitoringSystemID"/></td>
									<td><xsl:value-of select="../FuelCode"/></td>
									<td><xsl:value-of select="MaximumFuelFlowRate"/></td>
									<td><xsl:value-of select="SystemFuelFlowUOMCode"/></td>
									<xsl:if test="MaximumFuelFlowRateSourceCode = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="MaximumFuelFlowRateSourceCode != ''"><td><xsl:value-of select="MaximumFuelFlowRateSourceCode"/></td></xsl:if>
									<xsl:call-template name="Optional_BeginDate_Template"/>
									<xsl:call-template name="Optional_BeginHour_Template"/>
									<xsl:call-template name="Optional_EndDate_Template"/>
									<xsl:call-template name="Optional_EndHour_Template"/>
								</tr>
							</xsl:for-each>
						</tbody>
					</table>
				</xsl:if>				
				<!-- Component Data -->
				<xsl:if test="MonitoringPlan/MonitoringLocationData/StackPipeData/ComponentData | MonitoringPlan/MonitoringLocationData/UnitData/ComponentData">
					<br/>
					<table title="Component Data" border="1" width="100%" style="background-color:White;">
						<caption style="color:darkblue;text-align:left;">Component Data</caption>
						<tbody>
							<tr style="color:white;background-color:darkblue;">
								<th>Unit/Stack/Pipe Identifier</th>
								<th>Component Type</th>
								<th>Component ID</th>
								<th>SAM</th>
								<th>BAS</th>
								<th>Manufacturer</th>
								<th>Model or Version</th>
								<th>Serial Number</th>
								<th>Hg Converter Ind</th>
							</tr>
							<xsl:for-each select="MonitoringPlan/MonitoringLocationData/StackPipeData/ComponentData | MonitoringPlan/MonitoringLocationData/UnitData/ComponentData">
								<xsl:sort select="BeginDate"/>
								<tr>
									<xsl:choose>
										<xsl:when test="../../StackPipeID != ''">
											<td><xsl:value-of select="../../StackPipeID"/></td>
										</xsl:when>
										<xsl:otherwise>
											<td><xsl:value-of select="../../UnitID"/></td>
										</xsl:otherwise>
									</xsl:choose>
									<td><xsl:value-of select="ComponentTypeCode"/></td>
									<td><xsl:value-of select="ComponentID"/></td>
									<xsl:if test="SampleAcquisitionMethodCode = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="SampleAcquisitionMethodCode != ''"><td><xsl:value-of select="SampleAcquisitionMethodCode"/></td></xsl:if>
									<xsl:if test="BasisCode = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="BasisCode != ''"><td><xsl:value-of select="BasisCode"/></td></xsl:if>
									<xsl:if test="Manufacturer = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="Manufacturer != ''"><td><xsl:value-of select="Manufacturer"/></td></xsl:if>
									<xsl:if test="ModelVersion = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="ModelVersion != ''"><td><xsl:value-of select="ModelVersion"/></td></xsl:if>
									<xsl:if test="SerialNumber = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="SerialNumber != ''"><td><xsl:value-of select="SerialNumber"/></td></xsl:if>
									<xsl:choose>
										<xsl:when test="HgConverterIndicator != ''"><td><xsl:value-of select="HgConverterIndicator"/></td></xsl:when>
										<xsl:otherwise><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:otherwise>
									</xsl:choose>
								</tr>
							</xsl:for-each>
						</tbody>
					</table>
				</xsl:if>				
				<!-- Analyzer Range Data -->
				<xsl:if test="MonitoringPlan/MonitoringLocationData/StackPipeData/ComponentData/AnalyzerRangeData | MonitoringPlan/MonitoringLocationData/UnitData/ComponentData/AnalyzerRangeData">
					<br/>
					<table title="Analyzer Range Data" border="1" width="100%" style="background-color:White;">
						<caption style="color:darkblue;text-align:left;">Analyzer Range Data</caption>
						<tbody>
							<tr style="color:white;background-color:darkblue;">
								<th>Unit/Stack/Pipe Identifier</th>
								<th>Component Type</th>
								<th>Component ID</th>
								<th>Range Code</th>
								<th>Dual Range Indicator</th>
								<th>Begin Date</th>
								<th>Begin Hour</th>
								<th>End Date</th>
								<th>End Hour</th>
							</tr>
							<xsl:for-each select="MonitoringPlan/MonitoringLocationData/StackPipeData/ComponentData/AnalyzerRangeData | MonitoringPlan/MonitoringLocationData/UnitData/ComponentData/AnalyzerRangeData">
								<xsl:sort select="BeginDate"/>
								<tr>
									<xsl:choose>
										<xsl:when test="../../../StackPipeID != ''">
											<td><xsl:value-of select="../../../StackPipeID"/></td>
										</xsl:when>
										<xsl:otherwise>
											<td><xsl:value-of select="../../../UnitID"/></td>
										</xsl:otherwise>
									</xsl:choose>
									<td><xsl:value-of select="../ComponentTypeCode"/></td>
									<td><xsl:value-of select="../ComponentID"/></td>
									<td><xsl:value-of select="AnalyzerRangeCode"/></td>
									<xsl:if test="DualRangeIndicator = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="DualRangeIndicator != ''"><td><xsl:value-of select="DualRangeIndicator"/></td></xsl:if>
									<xsl:call-template name="Optional_BeginDate_Template"/>
									<xsl:call-template name="Optional_BeginHour_Template"/>
									<xsl:call-template name="Optional_EndDate_Template"/>
									<xsl:call-template name="Optional_EndHour_Template"/>
								</tr>
							</xsl:for-each>
						</tbody>
					</table>
				</xsl:if>				
				<!-- Emissions Formulas -->
				<xsl:if test="MonitoringPlan/MonitoringLocationData/StackPipeData/MonitoringFormulaData | MonitoringPlan/MonitoringLocationData/UnitData/MonitoringFormulaData">
					<br/>
					<table title="Emissions Formulas" border="1" width="100%" style="background-color:White;">
						<caption style="color:darkblue;text-align:left;">Emissions Formulas</caption>
						<tbody>
							<tr style="color:white;background-color:darkblue;">
								<th>Unit/Stack/Pipe Identifier</th>
								<th>Parameter</th>
								<th>Formula ID</th>
								<th>Formula Code</th>
								<th>Formula</th>
								<th>Begin Date</th>
								<th>Begin Hour</th>
								<th>End Date</th>
								<th>End Hour</th>
							</tr>
							<xsl:for-each select="MonitoringPlan/MonitoringLocationData/StackPipeData/MonitoringFormulaData | MonitoringPlan/MonitoringLocationData/UnitData/MonitoringFormulaData">
								<xsl:sort select="BeginDate"/>
								<tr>
									<xsl:choose>
										<xsl:when test="../../StackPipeID != ''">
											<td><xsl:value-of select="../../StackPipeID"/></td>
										</xsl:when>
										<xsl:otherwise>
											<td><xsl:value-of select="../../UnitID"/></td>
										</xsl:otherwise>
									</xsl:choose>
									<td><xsl:value-of select="ParameterCode"/></td>
									<td><xsl:value-of select="FormulaID"/></td>
									<xsl:if test="FormulaCode = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="FormulaCode != ''"><td><xsl:value-of select="FormulaCode"/></td></xsl:if>
									<xsl:if test="FormulaText = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="FormulaText != ''"><td><xsl:value-of select="FormulaText"/></td></xsl:if>
									<xsl:call-template name="Optional_BeginDate_Template"/>
									<xsl:call-template name="Optional_BeginHour_Template"/>
									<xsl:call-template name="Optional_EndDate_Template"/>
									<xsl:call-template name="Optional_EndHour_Template"/>
								</tr>
							</xsl:for-each>
						</tbody>
					</table>
				</xsl:if>				
				<!-- Span Values -->
				<xsl:if test="MonitoringPlan/MonitoringLocationData/StackPipeData/MonitoringSpanData | MonitoringPlan/MonitoringLocationData/UnitData/MonitoringSpanData">
					<br/>
					<table title="Span Values" border="1" width="100%" style="background-color:White;">
						<caption style="color:darkblue;text-align:left;">Span Values</caption>
						<tbody>
							<tr style="color:white;background-color:darkblue;">
								<th>Unit/Stack/Pipe Identifier</th>
								<th>Comp Type</th>
								<th>Scale</th>
								<th>Method</th>
								<th>MPC</th>
								<th>MPF</th>
								<th>MEC</th>
								<th>Span Value (ppm)</th>
								<th>Full-Scale Range</th>
								<th>Units of Measure</th>
								<th>Scale Transition Point</th>
								<th>Def. High Range Value</th>
								<th>Flow Full Range (SCFH)</th>
								<th>Flow Span Value (SCFH)</th>
								<th>Begin Date</th>
								<th>Begin Hour</th>
								<th>End Date</th>
								<th>End Hour</th>
							</tr>
							<xsl:for-each select="MonitoringPlan/MonitoringLocationData/StackPipeData/MonitoringSpanData | MonitoringPlan/MonitoringLocationData/UnitData/MonitoringSpanData">
								<xsl:sort select="BeginDate"/>
								<tr>
									<xsl:choose>
										<xsl:when test="../../StackPipeID != ''">
											<td><xsl:value-of select="../../StackPipeID"/></td>
										</xsl:when>
										<xsl:otherwise>
											<td><xsl:value-of select="../../UnitID"/></td>
										</xsl:otherwise>
									</xsl:choose>
									<td><xsl:value-of select="ComponentTypeCode"/></td>
									<xsl:if test="SpanScaleCode = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="SpanScaleCode != ''"><td><xsl:value-of select="SpanScaleCode"/></td></xsl:if>
									<xsl:if test="SpanMethodCode = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="SpanMethodCode != ''"><td><xsl:value-of select="SpanMethodCode"/></td></xsl:if>
									<xsl:if test="MPCValue = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="MPCValue != ''"><td><xsl:value-of select="MPCValue"/></td></xsl:if>
									<xsl:if test="MPFValue = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="MPFValue != ''"><td><xsl:value-of select="MPFValue"/></td></xsl:if>
									<xsl:if test="MECValue = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="MECValue != ''"><td><xsl:value-of select="MECValue"/></td></xsl:if>
									<xsl:if test="SpanValue = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="SpanValue != ''"><td><xsl:value-of select="SpanValue"/></td></xsl:if>
									<xsl:if test="FullScaleRange = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="FullScaleRange != ''"><td><xsl:value-of select="FullScaleRange"/></td></xsl:if>
									<xsl:if test="SpanUnitsOfMeasureCode = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="SpanUnitsOfMeasureCode != ''"><td><xsl:value-of select="SpanUnitsOfMeasureCode"/></td></xsl:if>
									<xsl:if test="ScaleTransitionPoint = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="ScaleTransitionPoint != ''"><td><xsl:value-of select="ScaleTransitionPoint"/></td></xsl:if>
									<xsl:if test="DefaultHighRange = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="DefaultHighRange != ''"><td><xsl:value-of select="DefaultHighRange"/></td></xsl:if>
									<xsl:if test="FlowFullScaleRange = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="FlowFullScaleRange != ''"><td><xsl:value-of select="FlowFullScaleRange"/></td></xsl:if>
									<xsl:if test="FlowSpanValue = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="FlowSpanValue != ''"><td><xsl:value-of select="FlowSpanValue"/></td></xsl:if>
									<td><xsl:value-of select="BeginDate"/></td>
									<td><xsl:value-of select="BeginHour"/></td>
									<xsl:call-template name="Optional_EndDate_Template"/>
									<xsl:call-template name="Optional_EndHour_Template"/>
								</tr>
							</xsl:for-each>
						</tbody>
					</table>
				</xsl:if>				
				<!-- Rect Duct WAF -->
				<xsl:if test="MonitoringPlan/MonitoringLocationData/StackPipeData/RectangularDuctWAFData | MonitoringPlan/MonitoringLocationData/UnitData/RectangularDuctWAFData">
					<br/>
					<table title="Rectangular Duct WAF" border="1" width="100%" style="background-color:White;">
						<caption style="color:darkblue;text-align:left;">Rectangular Duct WAF</caption>
						<tbody>
							<tr style="color:white;background-color:darkblue;">
								<th>Unit/Stack/Pipe Identifier</th>
								<th>WAF Determin. Date</th>
								<th>WAF Effective Date</th>
								<th>WAF Effective Hour</th>
								<th>WAF Method Code</th>
								<th>WAF Value</th>
								<th>Number of Test Runs</th>
								<th>Number of T. Points WAF</th>
								<th>Number of Test Ports</th>
								<th>Number of T. Points Ref</th>
								<th>Duct Width (ft)</th>
								<th>Duct Depth (ft)</th>
								<th>WAF End Date</th>
								<th>WAF End Hour</th>
							</tr>
							<xsl:for-each select="MonitoringPlan/MonitoringLocationData/StackPipeData/RectangularDuctWAFData | MonitoringPlan/MonitoringLocationData/UnitData/RectangularDuctWAFData">
								<xsl:sort select="BeginDate"/>
								<tr>
									<xsl:choose>
										<xsl:when test="../../StackPipeID != ''">
											<td><xsl:value-of select="../../StackPipeID"/></td>
										</xsl:when>
										<xsl:otherwise>
											<td><xsl:value-of select="../../UnitID"/></td>
										</xsl:otherwise>
									</xsl:choose>
									<xsl:if test="WAFDeterminationDate = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="WAFDeterminationDate != ''"><td><xsl:value-of select="WAFDeterminationDate"/></td></xsl:if>
									<td><xsl:value-of select="WAFBeginDate"/></td>
									<td><xsl:value-of select="WAFBeginHour"/></td>
									<xsl:if test="WAFMethodCode = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="WAFMethodCode != ''"><td><xsl:value-of select="WAFMethodCode"/></td></xsl:if>
									<td><xsl:value-of select="WAFValue"/></td>
									<xsl:if test="NumberOfTestRuns = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="NumberOfTestRuns != ''"><td><xsl:value-of select="NumberOfTestRuns"/></td></xsl:if>
									<xsl:if test="NumberOfTraversePointsWAF = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="NumberOfTraversePointsWAF != ''"><td><xsl:value-of select="NumberOfTraversePointsWAF"/></td></xsl:if>
									<xsl:if test="NumberOfTestPorts = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="NumberOfTestPorts != ''"><td><xsl:value-of select="NumberOfTestPorts"/></td></xsl:if>
									<xsl:if test="NumberOfTraversePointsRef = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="NumberOfTraversePointsRef != ''"><td><xsl:value-of select="NumberOfTraversePointsRef"/></td></xsl:if>
									<xsl:if test="DuctWidth = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="DuctWidth != ''"><td><xsl:value-of select="DuctWidth"/></td></xsl:if>
									<xsl:if test="DuctDepth = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="DuctDepth != ''"><td><xsl:value-of select="DuctDepth"/></td></xsl:if>
									<xsl:call-template name="Optional_EndDate_Template"/>
									<xsl:call-template name="Optional_EndHour_Template"/>
								</tr>
							</xsl:for-each>
						</tbody>
					</table>
				</xsl:if>				
				<!-- Unit/Stack/Pipe Load or Op Level Info -->
				<xsl:if test="MonitoringPlan/MonitoringLocationData/StackPipeData/MonitoringLoadData | MonitoringPlan/MonitoringLocationData/UnitData/MonitoringLoadData">
					<br/>
					<table title="Unit/Stack/Pipe Load or Operating Level Information" border="1" width="100%" style="background-color:White;">
						<caption style="color:darkblue;text-align:left;">Unit/Stack/Pipe Load or Operating Level Information</caption>
						<tbody>
							<tr style="color:white;background-color:darkblue;">
								<th>Unit/Stack/Pipe Identifier</th>
								<th>Maximum Hourly Load</th>
								<th>Units of Measure</th>
								<th>Upper Bound of Range of Operation</th>
								<th>Lower Bound of Range of Operation</th>
								<th>Designated Normal Op. Level</th>
								<th>Second Most Frequently Used Op. Level</th>
								<th>Second Normal Indicator</th>
								<th>Load Analysis Date</th>
								<th>Begin Date</th>
								<th>Begin Hour</th>
								<th>End Date</th>
								<th>End Hour</th>
							</tr>
							<xsl:for-each select="MonitoringPlan/MonitoringLocationData/StackPipeData/MonitoringLoadData | MonitoringPlan/MonitoringLocationData/UnitData/MonitoringLoadData">
								<xsl:sort select="BeginDate"/>
								<tr>
									<xsl:choose>
										<xsl:when test="../../StackPipeID != ''">
											<td><xsl:value-of select="../../StackPipeID"/></td>
										</xsl:when>
										<xsl:otherwise>
											<td><xsl:value-of select="../../UnitID"/></td>
										</xsl:otherwise>
									</xsl:choose>
									<xsl:if test="MaximumLoadValue = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="MaximumLoadValue != ''"><td><xsl:value-of select="MaximumLoadValue"/></td></xsl:if>
									<xsl:if test="MaximumLoadUnitsOfMeasureCode = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="MaximumLoadUnitsOfMeasureCode != ''"><td><xsl:value-of select="MaximumLoadUnitsOfMeasureCode"/></td></xsl:if>
									<xsl:if test="UpperOperationBoundary = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="UpperOperationBoundary != ''"><td><xsl:value-of select="UpperOperationBoundary"/></td></xsl:if>
									<xsl:if test="LowerOperationBoundary = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="LowerOperationBoundary != ''"><td><xsl:value-of select="LowerOperationBoundary"/></td></xsl:if>
									<xsl:if test="NormalLevelCode = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="NormalLevelCode != ''"><td><xsl:value-of select="NormalLevelCode"/></td></xsl:if>
									<xsl:if test="SecondLevelCode = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="SecondLevelCode != ''"><td><xsl:value-of select="SecondLevelCode"/></td></xsl:if>
									<xsl:if test="SecondNormalIndicator = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="SecondNormalIndicator != ''"><td><xsl:value-of select="SecondNormalIndicator"/></td></xsl:if>
									<xsl:if test="LoadAnalysisDate = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="LoadAnalysisDate != ''"><td><xsl:value-of select="LoadAnalysisDate"/></td></xsl:if>
									<td><xsl:value-of select="BeginDate"/></td>
									<td><xsl:value-of select="BeginHour"/></td>
									<xsl:call-template name="Optional_EndDate_Template"/>
									<xsl:call-template name="Optional_EndHour_Template"/>
								</tr>
							</xsl:for-each>
						</tbody>
					</table>
				</xsl:if>				
				<!-- Monitoring Defaults -->
				<xsl:if test="MonitoringPlan/MonitoringLocationData/StackPipeData/MonitoringDefaultData | MonitoringPlan/MonitoringLocationData/UnitData/MonitoringDefaultData">
					<br/>
					<table title="Monitoring Defaults" border="1" width="100%" style="background-color:White;">
						<caption style="color:darkblue;text-align:left;">Monitoring Defaults</caption>
						<tbody>
							<tr style="color:white;background-color:darkblue;">
								<th>Unit/Stack/Pipe Identifier</th>
								<th>Parameter</th>
								<th>Value</th>
								<th>Units of Measure</th>
								<th>Purpose Code</th>
								<th>Fuel Type</th>
								<th>Operating Condition</th>
								<th>Source of Value</th>
								<th>Group Identifier</th>
								<th>Begin Date</th>
								<th>Begin Hour</th>
								<th>End Date</th>
								<th>End Hour</th>
							</tr>
							<xsl:for-each select="MonitoringPlan/MonitoringLocationData/StackPipeData/MonitoringDefaultData | MonitoringPlan/MonitoringLocationData/UnitData/MonitoringDefaultData">
								<xsl:sort select="BeginDate"/>
								<tr>
									<xsl:choose>
										<xsl:when test="../../StackPipeID != ''">
											<td><xsl:value-of select="../../StackPipeID"/></td>
										</xsl:when>
										<xsl:otherwise>
											<td><xsl:value-of select="../../UnitID"/></td>
										</xsl:otherwise>
									</xsl:choose>
									<td><xsl:value-of select="ParameterCode"/></td>
									<td><xsl:value-of select="DefaultValue"/></td>
									<xsl:if test="DefaultUnitsOfMeasureCode = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="DefaultUnitsOfMeasureCode != ''"><td><xsl:value-of select="DefaultUnitsOfMeasureCode"/></td></xsl:if>
									<xsl:if test="DefaultPurposeCode = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="DefaultPurposeCode != ''"><td><xsl:value-of select="DefaultPurposeCode"/></td></xsl:if>
									<xsl:if test="FuelCode = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="FuelCode != ''"><td><xsl:value-of select="FuelCode"/></td></xsl:if>
									<xsl:if test="OperatingConditionCode = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="OperatingConditionCode != ''"><td><xsl:value-of select="OperatingConditionCode"/></td></xsl:if>
									<xsl:if test="DefaultSourceCode = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="DefaultSourceCode != ''"><td><xsl:value-of select="DefaultSourceCode"/></td></xsl:if>
									<xsl:if test="GroupID = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
									<xsl:if test="GroupID != ''"><td><xsl:value-of select="GroupID"/></td></xsl:if>
									<td><xsl:value-of select="BeginDate"/></td>
									<td><xsl:value-of select="BeginHour"/></td>
									<xsl:call-template name="Optional_EndDate_Template"/>
									<xsl:call-template name="Optional_EndHour_Template"/>
								</tr>
							</xsl:for-each>
						</tbody>
					</table>
				</xsl:if>				
				<!-- Monitor Qualification Data -->
				<xsl:if test="MonitoringPlan/MonitoringLocationData/StackPipeData/MonitoringQualificationData | MonitoringPlan/MonitoringLocationData/UnitData/MonitoringQualificationData">
					<br/>				
					<table title="Qualifications" border="1" width="100%" style="border-color:darkblue;border-width:1px;background-color:White;">
					    <caption style="color:darkblue;text-align:left;">Qualifications</caption>
						<tbody>
							<tr style="color:white;background-color:darkblue;">
								<th>Unit/Stack/Pipe Identifier</th>
								<th>Qualification Type</th>
								<th>Begin Date</th>
								<th>End Date</th>
							</tr>
							<xsl:for-each select="MonitoringPlan/MonitoringLocationData/StackPipeData/MonitoringQualificationData | MonitoringPlan/MonitoringLocationData/UnitData/MonitoringQualificationData">
								<tr>
									<xsl:choose>
										<xsl:when test="../../StackPipeID != ''">
											<td><xsl:value-of select="../../StackPipeID"/></td>
										</xsl:when>
										<xsl:otherwise>
											<td><xsl:value-of select="../../UnitID"/></td>
										</xsl:otherwise>
									</xsl:choose>
									<td><xsl:value-of select="QualificationTypeCode"/></td>
									<td><xsl:value-of select="BeginDate"/></td>
									<xsl:call-template name="Optional_EndDate_Template"/>
								</tr>
							</xsl:for-each>
						</tbody>
					</table>
					<!-- Monitor Qual - PCT -->
					<xsl:if test="MonitoringPlan/MonitoringLocationData/StackPipeData/MonitoringQualificationData/MonitoringQualPercentData | MonitoringPlan/MonitoringLocationData/UnitData/MonitoringQualificationData/MonitoringQualPercentData">
						<br/>
						<table title="Qualification Percentages" border="1" width="95%" style="border-color:darkblue;border-width:1px;background-color:White;">
							<caption style="color:darkblue;text-align:left;">Qualification Percentages</caption>
							<tbody>
								<tr style="color:white;background-color:darkblue;">
									<th>Unit/Stack/Pipe Identifier</th>
									<th>Qualification Type</th>
									<th>Qualification Year</th>
									<th>Average Percent Value</th>
									<th>Year 1 Data Year</th>
									<th>Year 1 Data Type Cd</th>
									<th>Year 1 Percent Value</th>
									<th>Year 2 Data Year</th>
									<th>Year 2 Data Type Cd</th>
									<th>Year 2 Percent Value</th>
									<th>Year 3 Data Year</th>
									<th>Year 3 Data Type Cd</th>
									<th>Year 3 Percent Value</th>
								</tr>
								<xsl:for-each select="MonitoringPlan/MonitoringLocationData/StackPipeData/MonitoringQualificationData/MonitoringQualPercentData | MonitoringPlan/MonitoringLocationData/UnitData/MonitoringQualificationData/MonitoringQualPercentData">
									<tr>
										<xsl:choose>
											<xsl:when test="../../../StackPipeID != ''">
												<td><xsl:value-of select="../../StackPipeID"/></td>
											</xsl:when>
											<xsl:otherwise>
												<td><xsl:value-of select="../../../UnitID"/></td>
											</xsl:otherwise>
										</xsl:choose>
										<td><xsl:value-of select="../QualificationTypeCode"/></td>
										<td><xsl:value-of select="QualificationYear"/></td>
										<xsl:if test="AveragePercentValue = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
										<xsl:if test="AveragePercentValue != ''"><td><xsl:value-of select="AveragePercentValue"/></td></xsl:if>
										<xsl:if test="Yr1QualificationDataYear = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
										<xsl:if test="Yr1QualificationDataYear != ''"><td><xsl:value-of select="Yr1QualificationDataYear"/></td></xsl:if>
										<xsl:if test="Yr1QualificationDataTypeCode = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
										<xsl:if test="Yr1QualificationDataTypeCode != ''"><td><xsl:value-of select="Yr1QualificationDataTypeCode"/></td></xsl:if>
										<xsl:if test="Yr1PercentageValue = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
										<xsl:if test="Yr1PercentageValue != ''"><td><xsl:value-of select="Yr1PercentageValue"/></td></xsl:if>
										<xsl:if test="Yr2QualificationDataYear = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
										<xsl:if test="Yr2QualificationDataYear != ''"><td><xsl:value-of select="Yr2QualificationDataYear"/></td></xsl:if>
										<xsl:if test="Yr2QualificationDataTypeCode = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
										<xsl:if test="Yr2QualificationDataTypeCode != ''"><td><xsl:value-of select="Yr2QualificationDataTypeCode"/></td></xsl:if>
										<xsl:if test="Yr2PercentageValue = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
										<xsl:if test="Yr2PercentageValue != ''"><td><xsl:value-of select="Yr2PercentageValue"/></td></xsl:if>
										<xsl:if test="Yr3QualificationDataYear = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
										<xsl:if test="Yr3QualificationDataYear != ''"><td><xsl:value-of select="Yr3QualificationDataYear"/></td></xsl:if>
										<xsl:if test="Yr3QualificationDataTypeCode = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
										<xsl:if test="Yr3QualificationDataTypeCode != ''"><td><xsl:value-of select="Yr3QualificationDataTypeCode"/></td></xsl:if>
										<xsl:if test="Yr3PercentageValue = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
										<xsl:if test="Yr3PercentageValue != ''"><td><xsl:value-of select="Yr3PercentageValue"/></td></xsl:if>
									</tr>
								</xsl:for-each>
							</tbody>
						</table>
					</xsl:if>
										<!-- Monitor Qual - LEE -->
					<xsl:if test="MonitoringPlan/MonitoringLocationData/StackPipeData/MonitoringQualificationData/MonitoringQualLEEData | MonitoringPlan/MonitoringLocationData/UnitData/MonitoringQualificationData/MonitoringQualLEEData">
						<br/>
						<table title="LME Qualification" border="1" width="95%" style="border-color:darkblue;border-width:1px;background-color:White;">
							<caption style="color:darkblue;text-align:left;">LEE Qualification</caption>
							<tbody>
								<tr style="color:white;background-color:darkblue;">
									<th>Unit/Stack/Pipe Identifier</th>
									<th>Qualification Type</th>
									<th>Qualification Test Date</th>
									<th>Parameter Code</th>
									<th>Qualification Test Type</th>
									<th>Potential Annual Mass Emissions</th>
									<th>Applicable Emission Standard</th>
									<th>Units of Standard</th>
									<th>Percentage Of Emission Standard</th>
								</tr>
								<xsl:for-each select="MonitoringPlan/MonitoringLocationData/StackPipeData/MonitoringQualificationData/MonitoringQualLEEData | MonitoringPlan/MonitoringLocationData/UnitData/MonitoringQualificationData/MonitoringQualLEEData">
									<tr>
										<xsl:choose>
											<xsl:when test="../../../StackPipeID != ''">
												<td><xsl:value-of select="../../../StackPipeID"/></td>
											</xsl:when>
											<xsl:otherwise>
												<td><xsl:value-of select="../../../UnitID"/></td>
											</xsl:otherwise>
										</xsl:choose>
										<td><xsl:value-of select="../QualificationTypeCode"/></td>
										<td><xsl:value-of select="QualificationTestDate"/></td>
										<td><xsl:value-of select="ParameterCode"/></td>
										<td><xsl:value-of select="QualificationTestType"/></td>
										<xsl:if test="PotentialAnnualMassEmissions = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
										<xsl:if test="PotentialAnnualMassEmissions != ''"><td><xsl:value-of select="PotentialAnnualMassEmissions"/></td></xsl:if>
										<xsl:if test="ApplicableEmissionStandard = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
										<xsl:if test="ApplicableEmissionStandard != ''"><td><xsl:value-of select="ApplicableEmissionStandard"/></td></xsl:if>
										<xsl:if test="UnitsofStandard = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
										<xsl:if test="UnitsofStandard != ''"><td><xsl:value-of select="UnitsofStandard"/></td></xsl:if>
										<xsl:if test="PercentageOfEmissionStandard = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
										<xsl:if test="PercentageOfEmissionStandard != ''"><td><xsl:value-of select="PercentageOfEmissionStandard"/></td></xsl:if>
									</tr>
								</xsl:for-each>
							</tbody>
						</table>
					</xsl:if>

					<!-- Monitor Qual - LME -->
					<xsl:if test="MonitoringPlan/MonitoringLocationData/StackPipeData/MonitoringQualificationData/MonitoringQualLMEData | MonitoringPlan/MonitoringLocationData/UnitData/MonitoringQualificationData/MonitoringQualLMEData">
						<br/>
						<table title="LME Qualification" border="1" width="95%" style="border-color:darkblue;border-width:1px;background-color:White;">
							<caption style="color:darkblue;text-align:left;">LME Qualification</caption>
							<tbody>
								<tr style="color:white;background-color:darkblue;">
									<th>Unit/Stack/Pipe Identifier</th>
									<th>Qualification Type</th>
									<th>Qualification Data Year</th>
									<th>Operating Hours</th>
									<th>SO2 Tons</th>
									<th>NOx Tons</th>
								</tr>
								<xsl:for-each select="MonitoringPlan/MonitoringLocationData/StackPipeData/MonitoringQualificationData/MonitoringQualLMEData | MonitoringPlan/MonitoringLocationData/UnitData/MonitoringQualificationData/MonitoringQualLMEData">
									<tr>
										<xsl:choose>
											<xsl:when test="../../../StackPipeID != ''">
												<td><xsl:value-of select="../../../StackPipeID"/></td>
											</xsl:when>
											<xsl:otherwise>
												<td><xsl:value-of select="../../../UnitID"/></td>
											</xsl:otherwise>
										</xsl:choose>
										<td><xsl:value-of select="../QualificationTypeCode"/></td>
										<td><xsl:value-of select="QualificationDataYear"/></td>
										<xsl:if test="OperatingHours = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
										<xsl:if test="OperatingHours != ''"><td><xsl:value-of select="OperatingHours"/></td></xsl:if>
										<xsl:if test="SO2Tons = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
										<xsl:if test="SO2Tons != ''"><td><xsl:value-of select="SO2Tons"/></td></xsl:if>
										<xsl:if test="NOxTons = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
										<xsl:if test="NOxTons != ''"><td><xsl:value-of select="NOxTons"/></td></xsl:if>
									</tr>
								</xsl:for-each>
							</tbody>
						</table>
					</xsl:if>
				</xsl:if>
				<!-- MP Comments  -->
				<xsl:if test="MonitoringPlan/MonitoringPlanCommentData">
					<br/>
					<table title="Monitoring Plan Comments" border="1" width="100%" style="background-color:White;">
						<caption style="color:darkblue;text-align:left;">Monitoring Plan Comments</caption>
						<tbody>
							<tr style="color:white;background-color:darkblue;">
								<th>Comments</th>
								<th>Begin Date</th>
								<th>End Date</th>
							</tr>
							<xsl:for-each select="MonitoringPlan/MonitoringPlanCommentData">
								<xsl:sort select="BeginDate"/>
								<tr>
									<td><xsl:value-of select="MonitoringPlanComment"/></td>
									<td><xsl:value-of select="BeginDate"/></td>
									<xsl:call-template name="Optional_EndDate_Template"/>
								</tr>
							</xsl:for-each>
						</tbody>
					</table>
				</xsl:if>
			</body>
		</html>
	</xsl:template>

	<xsl:template name="Optional_BeginDate_Template" match="BeginDate">
		<!-- add a space to EndDate if it is not there - this is the hard way, but it works -->
		<xsl:if test="BeginDate = ''"><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
		<xsl:if test="BeginDate != ''"><td><xsl:value-of select="BeginDate"/></td></xsl:if>
	</xsl:template>
	<xsl:template name="Optional_BeginHour_Template" match="BeginHour">
		<!-- add a space to EndHour if it is not there - this is the hard way, but it works -->
		<xsl:if test="BeginHour = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
		<xsl:if test="BeginHour != ''"><td><xsl:value-of select="BeginHour"/></td></xsl:if>
	</xsl:template>
	<xsl:template name="Optional_EndDate_Template" match="EndDate | WAFEndDate">
		<!-- add a space to EndDate if it is not there - this is the hard way, but it works -->
		<xsl:if test="EndDate = ''"><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
		<xsl:if test="EndDate != ''"><td><xsl:value-of select="EndDate"/></td></xsl:if>
		<xsl:if test="WAFEndDate = ''"><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
		<xsl:if test="WAFEndDate != ''"><td><xsl:value-of select="WAFEndDate"/></td></xsl:if>
	</xsl:template>
	<xsl:template name="Optional_EndHour_Template" match="EndHour | WAFEndHour">
		<!-- add a space to EndHour if it is not there - this is the hard way, but it works -->
		<xsl:if test="EndHour = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
		<xsl:if test="EndHour != ''"><td><xsl:value-of select="EndHour"/></td></xsl:if>
		<xsl:if test="WAFEndHour = '' "><td> <xsl:text disable-output-escaping="yes"> &amp;nbsp;</xsl:text> </td></xsl:if>
		<xsl:if test="WAFEndHour != ''"><td><xsl:value-of select="WAFEndHour"/></td></xsl:if>
	</xsl:template>
</xsl:stylesheet>